pub enum NetworkTokenResolverRequest {
ResolveToken {
token: NetworkToken,
responder: NetworkTokenResolverResolveTokenResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: NetworkTokenResolverControlHandle,
method_type: MethodType,
},
}Expand description
Protocol to allow operations on NetworkToken objects, including resolving
NetworkToken to its canonical form.
Variants
ResolveToken
Resolves a network token to a canonical form.
Since a “default network” network token is a distinct token from the non-default network variant, there needs to be a way to disambiguate the pair.
Since a “default network” token (i.e. a token obtained from
[Networks.WatchDefault]) is a distinct token from the non-default
network variant, there needs to be a way to disambiguate the pair. If a
non-default network token is passed, the same token is returned.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: NetworkTokenResolverControlHandle
method_type: MethodTypeImplementations
Sourceimpl NetworkTokenResolverRequest
impl NetworkTokenResolverRequest
pub fn into_resolve_token( self, ) -> Option<(NetworkToken, NetworkTokenResolverResolveTokenResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL