pub enum NetworksRequest {
WatchDefault {
responder: NetworksWatchDefaultResponder,
},
WatchProperties {
payload: NetworksWatchPropertiesRequest,
responder: NetworksWatchPropertiesResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: NetworksControlHandle,
method_type: MethodType,
},
}Expand description
Protocol for acquiring NetworkTokens, and querying properties of that
network.
Variants
WatchDefault
Watches for changes in the default network.
The first call always returns a NetworkToken representing the
current default network, or if one is not present, blocks until a
default network is set. Subsequent calls block until the default
network has changed, or has been lost, returning a new NetworkToken
for the updated default network, or [no_default_network] if the
network is lost.
Only one call to this method may be pending per connection.
Fields
responder: NetworksWatchDefaultResponderWatchProperties
Registers a [PropertyWatcher] to watch for changes in requested
properties for the given NetworkToken.
The watcher receives updates for the requested properties on the
network represented by network.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
control_handle: NetworksControlHandlemethod_type: MethodTypeImplementations
Sourceimpl NetworksRequest
impl NetworksRequest
pub fn into_watch_default(self) -> Option<NetworksWatchDefaultResponder>
pub fn into_watch_properties( self, ) -> Option<(NetworksWatchPropertiesRequest, NetworksWatchPropertiesResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL