pub enum PropertyWatcherRequest {
Watch {
responder: PropertyWatcherWatchResponder,
},
}Expand description
A watcher for network property changes.
Variants
Watch
A hanging-get method that returns updates to the properties requested
when the watcher was created via [Networks.WatchProperties].
The first call returns a snapshot of all requested properties
for the watched network. Subsequent calls block until a property
has changed since the last call to Watch returned.
Only one call to this method may be pending at a time. Concurrent calls
on the same PropertyWatcher immediately closes the connection with
an zx.Status.ALREADY_EXISTS epitaph.
Fields

responder: PropertyWatcherWatchResponderImplementations
Sourceimpl PropertyWatcherRequest
impl PropertyWatcherRequest
pub fn into_watch(self) -> Option<PropertyWatcherWatchResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL