pub struct NetworkTokenResolverProxy { /* private fields */ }Implementations
Sourceimpl NetworkTokenResolverProxy
impl NetworkTokenResolverProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.net.policy.properties/NetworkTokenResolver.
Sourcepub fn take_event_stream(&self) -> NetworkTokenResolverEventStream
pub fn take_event_stream(&self) -> NetworkTokenResolverEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn resolve_token(
&self,
token: NetworkToken,
) -> QueryResponseFut<NetworkTokenResolverResolveTokenResult, DefaultFuchsiaResourceDialect>
pub fn resolve_token( &self, token: NetworkToken, ) -> QueryResponseFut<NetworkTokenResolverResolveTokenResult, DefaultFuchsiaResourceDialect>
Resolves a network token to a canonical form.
Since a “default network” network token is a distinct token from the non-default network variant, there needs to be a way to disambiguate the pair.
Since a “default network” token (i.e. a token obtained from
[Networks.WatchDefault]) is a distinct token from the non-default
network variant, there needs to be a way to disambiguate the pair. If a
non-default network token is passed, the same token is returned.