pub struct NetworkTokenResolverSynchronousProxy { /* private fields */ }Implementations
Sourceimpl NetworkTokenResolverSynchronousProxy
impl NetworkTokenResolverSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<NetworkTokenResolverEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<NetworkTokenResolverEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn resolve_token(
&self,
token: NetworkToken,
___deadline: MonotonicInstant,
) -> Result<NetworkTokenResolverResolveTokenResult, Error>
pub fn resolve_token( &self, token: NetworkToken, ___deadline: MonotonicInstant, ) -> Result<NetworkTokenResolverResolveTokenResult, Error>
Resolves a network token to a canonical form.
Since a “default network” network token is a distinct token from the non-default network variant, there needs to be a way to disambiguate the pair.
Since a “default network” token (i.e. a token obtained from
[Networks.WatchDefault]) is a distinct token from the non-default
network variant, there needs to be a way to disambiguate the pair. If a
non-default network token is passed, the same token is returned.