pub struct NetworksProxy { /* private fields */ }Implementations
Sourceimpl NetworksProxy
impl NetworksProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.net.policy.properties/Networks.
Sourcepub fn take_event_stream(&self) -> NetworksEventStream
pub fn take_event_stream(&self) -> NetworksEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn watch_default(
&self,
) -> QueryResponseFut<NetworksWatchDefaultResponse, DefaultFuchsiaResourceDialect> ⓘ
pub fn watch_default( &self, ) -> QueryResponseFut<NetworksWatchDefaultResponse, DefaultFuchsiaResourceDialect> ⓘ
Watches for changes in the default network.
The first call always returns a NetworkToken representing the
current default network, or if one is not present, blocks until a
default network is set. Subsequent calls block until the default
network has changed, or has been lost, returning a new NetworkToken
for the updated default network, or [no_default_network] if the
network is lost.
Only one call to this method may be pending per connection.
Sourcepub fn watch_properties(
&self,
payload: NetworksWatchPropertiesRequest,
) -> QueryResponseFut<NetworksWatchPropertiesResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn watch_properties( &self, payload: NetworksWatchPropertiesRequest, ) -> QueryResponseFut<NetworksWatchPropertiesResult, DefaultFuchsiaResourceDialect> ⓘ
Registers a [PropertyWatcher] to watch for changes in requested
properties for the given NetworkToken.
The watcher receives updates for the requested properties on the
network represented by network.