pub struct PropertyWatcherMarker;Trait Implementations
Sourceimpl Clone for PropertyWatcherMarker
impl Clone for PropertyWatcherMarker
Sourcefn clone(&self) -> PropertyWatcherMarker
fn clone(&self) -> PropertyWatcherMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PropertyWatcherMarker
Sourceimpl Debug for PropertyWatcherMarker
impl Debug for PropertyWatcherMarker
impl Eq for PropertyWatcherMarker
Sourceimpl Hash for PropertyWatcherMarker
impl Hash for PropertyWatcherMarker
Sourceimpl Ord for PropertyWatcherMarker
impl Ord for PropertyWatcherMarker
Sourcefn cmp(&self, other: &PropertyWatcherMarker) -> Ordering
fn cmp(&self, other: &PropertyWatcherMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for PropertyWatcherMarker
impl PartialEq for PropertyWatcherMarker
Sourceimpl PartialOrd for PropertyWatcherMarker
impl PartialOrd for PropertyWatcherMarker
Sourceimpl ProtocolMarker for PropertyWatcherMarker
impl ProtocolMarker for PropertyWatcherMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) PropertyWatcher"
const DEBUG_NAME: &'static str = "(anonymous) PropertyWatcher"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = PropertyWatcherProxy
type Proxy = PropertyWatcherProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = PropertyWatcherRequestStream
type RequestStream = PropertyWatcherRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = PropertyWatcherSynchronousProxy
type SynchronousProxy = PropertyWatcherSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for PropertyWatcherMarker