pub struct PropertyWatcherProxy { /* private fields */ }Implementations
Sourceimpl PropertyWatcherProxy
impl PropertyWatcherProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.net.policy.properties/PropertyWatcher.
Sourcepub fn take_event_stream(&self) -> PropertyWatcherEventStream
pub fn take_event_stream(&self) -> PropertyWatcherEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn watch(
&self,
) -> QueryResponseFut<PropertyWatcherWatchResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn watch( &self, ) -> QueryResponseFut<PropertyWatcherWatchResult, DefaultFuchsiaResourceDialect> ⓘ
A hanging-get method that returns updates to the properties requested
when the watcher was created via [Networks.WatchProperties].
The first call returns a snapshot of all requested properties
for the watched network. Subsequent calls block until a property
has changed since the last call to Watch returned.
Only one call to this method may be pending at a time. Concurrent calls
on the same PropertyWatcher immediately closes the connection with
an zx.Status.ALREADY_EXISTS epitaph.