pub struct PropertyWatcherSynchronousProxy { /* private fields */ }Implementations
Sourceimpl PropertyWatcherSynchronousProxy
impl PropertyWatcherSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<PropertyWatcherEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<PropertyWatcherEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn watch(
&self,
___deadline: MonotonicInstant,
) -> Result<PropertyWatcherWatchResult, Error>
pub fn watch( &self, ___deadline: MonotonicInstant, ) -> Result<PropertyWatcherWatchResult, Error>
A hanging-get method that returns updates to the properties requested
when the watcher was created via [Networks.WatchProperties].
The first call returns a snapshot of all requested properties
for the watched network. Subsequent calls block until a property
has changed since the last call to Watch returned.
Only one call to this method may be pending at a time. Concurrent calls
on the same PropertyWatcher immediately closes the connection with
an zx.Status.ALREADY_EXISTS epitaph.