pub struct PropertyWatcherWatchResponse {
pub updates: PropertyUpdate,
}Fields
updates: PropertyUpdateA table of updates that have occurred since the last update was reported via this watcher. If a property changes multiple times between updates, only the most recent version is reported.